@@ -48,8 +48,9 @@
 
 
 #include "kpLogCategories.h"
-#include <kio/netaccess.h> // kdelibs4support
+#include <KJobWidgets>
 #include <KLocalizedString>
+#include <KIO/StatJob>
 
 #include <QColor>
 #include <QBitmap>
@@ -68,7 +69,7 @@ kpDocument::kpDocument (int w, int h,
         kpDocumentEnvironment *environ)
     : QObject (),
       m_constructorWidth (w), m_constructorHeight (h),
-      m_isFromURL (false),
+      m_isFromExistingURL (false),
       m_savedAtLeastOnceBefore (false),
       m_saveOptions (new kpDocumentSaveOptions ()),
       m_metaInfo (new kpDocumentMetaInfo ()),
@@ -136,28 +137,31 @@ QUrl kpDocument::url () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setURL (const QUrl &url, bool isFromURL)
+void kpDocument::setURL (const QUrl &url, bool isFromExistingURL)
 {
     m_url = url;
-    m_isFromURL = isFromURL;
+    m_isFromExistingURL = isFromExistingURL;
 }
 
 //---------------------------------------------------------------------
 
 // public
-bool kpDocument::isFromURL (bool checkURLStillExists) const
+bool kpDocument::isFromExistingURL () const
 {
-    if (!m_isFromURL) {
+    return m_isFromExistingURL;
+}
+
+//---------------------------------------------------------------------
+
+// public
+bool kpDocument::urlExists (const QUrl &url) const
+{
+    if (url.isEmpty()) {
         return false;
     }
-
-    if (!checkURLStillExists) {
-        return true;
-    }
-
-    return (!m_url.isEmpty () &&
-            KIO::NetAccess::exists (m_url, KIO::NetAccess::SourceSide/*open*/,
-                d->environ->dialogParent ()));
+    KIO::StatJob *job = KIO::stat (url, KIO::StatJob::SourceSide, 0);
+    KJobWidgets::setWindow (job, d->environ->dialogParent ());
+    return job->exec();
 }
 
 //---------------------------------------------------------------------
