@@ -55,17 +55,14 @@
 #include <kactioncollection.h>
 #include <KSharedConfig>
 #include <kconfiggroup.h>
+#include <KFileCustomDialog>
 #include <KPluralHandlingSpinBox>
-#include <kfiledialog.h> // kdelibs4support
-#include <kiconloader.h>
-#include <kio/netaccess.h> // kdelibs4support
 #include <kmessagebox.h>
 #include <krecentfilesaction.h>
 #include <kstandardshortcut.h>
 #include <kstandardaction.h>
 #include <ktoolinvocation.h>
 #include <KLocalizedString>
-#include <kdeprintdialog.h> // kdelibs4support
 
 #include "kpLogCategories.h"
 #include "commands/kpCommandHistory.h"
@@ -106,12 +103,12 @@ void kpMainWindow::setupFileMenuActions ()
 
     d->actionExport = ac->addAction(QStringLiteral("file_export"));
     d->actionExport->setText (i18n ("E&xport..."));
-    d->actionExport->setIcon(KDE::icon(QStringLiteral("document-export")));
+    d->actionExport->setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
     connect (d->actionExport, &QAction::triggered, this, &kpMainWindow::slotExport);
 
     d->actionScan = ac->addAction(QStringLiteral("file_scan"));
     d->actionScan->setText(i18n ("Scan..."));
-    d->actionScan->setIcon(SmallIcon("scanner"));
+    d->actionScan->setIcon(QIcon::fromTheme("scanner"));
 #if HAVE_KSANE
     connect (d->actionScan, &QAction::triggered, this, &kpMainWindow::slotScan);
 #else
@@ -124,13 +121,13 @@ void kpMainWindow::setupFileMenuActions ()
 
     d->actionProperties = ac->addAction (QStringLiteral("file_properties"));
     d->actionProperties->setText (i18n ("Properties"));
-    d->actionProperties->setIcon(KDE::icon(QStringLiteral("document-properties")));
+    d->actionProperties->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     connect (d->actionProperties, &QAction::triggered, this, &kpMainWindow::slotProperties);
 
     //d->actionRevert = KStandardAction::revert (this, SLOT (slotRevert()), ac);
     d->actionReload = ac->addAction (QStringLiteral("file_revert"));
     d->actionReload->setText (i18n ("Reloa&d"));
-    d->actionReload->setIcon(KDE::icon(QStringLiteral("view-refresh")));
+    d->actionReload->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     connect (d->actionReload, &QAction::triggered, this, &kpMainWindow::slotReload);
     ac->setDefaultShortcuts (d->actionReload, KStandardShortcut::reload ());
     slotEnableReload ();
@@ -422,7 +419,7 @@ bool kpMainWindow::open (const QUrl &url, bool newDocSameNameIfNotExist)
                                        newDocSameNameIfNotExist);
     if (newDoc)
     {
-        if (newDoc->isFromURL (false/*don't bother checking exists*/))
+        if (newDoc->isFromExistingURL ())
             addRecentURL (url);
         return true;
     }
@@ -748,8 +745,7 @@ bool kpMainWindow::save (bool localOnly)
         return saveAs (localOnly);
     }
 
-    if (d->document->save (false/*no overwrite prompt*/,
-                           !d->document->savedAtLeastOnceBefore ()/*lossy prompt*/))
+    if (d->document->save (!d->document->savedAtLeastOnceBefore ()/*lossy prompt*/))
     {
         addRecentURL (d->document->url ());
         return true;
@@ -780,7 +776,6 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
                                   bool localOnly,
                                   kpDocumentSaveOptions *chosenSaveOptions,
                                   bool isSavingForFirstTime,
-                                  bool *allowOverwritePrompt,
                                   bool *allowLossyPrompt)
 {
 #if DEBUG_KP_MAIN_WINDOW
@@ -807,10 +802,6 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
         *chosenSaveOptions = kpDocumentSaveOptions ();
     }
 
-    if (allowOverwritePrompt) {
-        *allowOverwritePrompt = true;  // play it safe for now
-    }
-
     if (allowLossyPrompt) {
         *allowLossyPrompt = true;  // play it safe for now
     }
@@ -891,17 +882,20 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
             docMetaInfo,
             this);
 
-    KFileDialog fd (QUrl (startURL), QString(), this,
-                    saveOptionsWidget);
-    saveOptionsWidget->setVisualParent (&fd);
+    KFileCustomDialog fd (QUrl (startURL), this);
+    fd.setOperationMode (KFileWidget::Saving);
     fd.setWindowTitle (caption);
-    fd.setOperationMode (KFileDialog::Saving);
-    fd.setMimeFilter (mimeTypes, fdSaveOptions.mimeType ());
+    fd.setCustomWidget (saveOptionsWidget);
+    KFileWidget *fw = fd.fileWidget();
+    fw->setConfirmOverwrite (true);
+    fw->setMimeFilter (mimeTypes, fdSaveOptions.mimeType ());
     if (localOnly) {
-        fd.setMode (KFile::File | KFile::LocalOnly);
+        fw->setMode (KFile::File | KFile::LocalOnly);
     }
 
-    connect (&fd, &KFileDialog::filterChanged,
+    saveOptionsWidget->setVisualParent (&fd);
+
+    connect (fw, &KFileWidget::filterChanged,
              saveOptionsWidget, &kpDocumentSaveOptionsWidget::setMimeType);
 
     if ( fd.exec() == QDialog::Accepted )
@@ -923,17 +917,11 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
             *chosenSaveOptions = newSaveOptions;
         }
 
-
-        bool shouldAllowOverwritePrompt =
-                (fd.selectedUrl () != QUrl (startURL) ||
-                 newSaveOptions.mimeType () != startSaveOptions.mimeType ());
-        if (allowOverwritePrompt)
-        {
-            *allowOverwritePrompt = shouldAllowOverwritePrompt;
-        #if DEBUG_KP_MAIN_WINDOW
-            qCDebug(kpLogMainWindow) << "\tallowOverwritePrompt=" << *allowOverwritePrompt;
-        #endif
+        const QList<QUrl> selectedUrls = fw->selectedUrls ();
+        if (selectedUrls.isEmpty()) { // shouldn't happen
+            return {};
         }
+        const QUrl selectedUrl = selectedUrls.at(0);
 
         if (allowLossyPrompt)
         {
@@ -942,7 +930,7 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
             //        need to continually warn due to quality change)
             *allowLossyPrompt =
                 (isSavingForFirstTime ||
-                 shouldAllowOverwritePrompt ||
+                 selectedUrl != QUrl (startURL) ||
                  newSaveOptions.mimeType () != startSaveOptions.mimeType () ||
                  newSaveOptions.colorDepth () != startSaveOptions.colorDepth () ||
                  newSaveOptions.dither () != startSaveOptions.dither ());
@@ -953,9 +941,9 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
 
 
     #if DEBUG_KP_MAIN_WINDOW
-        qCDebug(kpLogMainWindow) << "\tselectedUrl=" << fd.selectedUrl ();
+        qCDebug(kpLogMainWindow) << "\tselectedUrl=" << selectedUrl;
     #endif
-        return fd.selectedUrl ();
+        return selectedUrl;
     }
 
     return {};
@@ -968,7 +956,7 @@ QUrl kpMainWindow::askForSaveURL (const QString &caption,
 bool kpMainWindow::saveAs (bool localOnly)
 {
     kpDocumentSaveOptions chosenSaveOptions;
-    bool allowOverwritePrompt, allowLossyPrompt;
+    bool allowLossyPrompt;
     QUrl chosenURL = askForSaveURL (i18nc ("@title:window", "Save Image As"),
                                     d->document->url ().url (),
                                     d->document->imageWithSelection (),
@@ -978,7 +966,6 @@ bool kpMainWindow::saveAs (bool localOnly)
                                     localOnly,
                                     &chosenSaveOptions,
                                     !d->document->savedAtLeastOnceBefore (),
-                                    &allowOverwritePrompt,
                                     &allowLossyPrompt);
 
 
@@ -988,7 +975,6 @@ bool kpMainWindow::saveAs (bool localOnly)
 
 
     if (!d->document->saveAs (chosenURL, chosenSaveOptions,
-                             allowOverwritePrompt,
                              allowLossyPrompt))
     {
         return false;
@@ -1018,7 +1004,7 @@ bool kpMainWindow::slotExport ()
     toolEndShape ();
 
     kpDocumentSaveOptions chosenSaveOptions;
-    bool allowOverwritePrompt, allowLossyPrompt;
+    bool allowLossyPrompt;
     QUrl chosenURL = askForSaveURL (i18nc ("@title:window", "Export"),
                                     d->lastExportURL.url (),
                                     d->document->imageWithSelection (),
@@ -1028,7 +1014,6 @@ bool kpMainWindow::slotExport ()
                                     false/*allow remote files*/,
                                     &chosenSaveOptions,
                                     d->exportFirstTime,
-                                    &allowOverwritePrompt,
                                     &allowLossyPrompt);
 
 
@@ -1039,7 +1024,6 @@ bool kpMainWindow::slotExport ()
     if (!kpDocument::savePixmapToFile (d->document->imageWithSelection (),
                                        chosenURL,
                                        chosenSaveOptions, *d->document->metaInfo (),
-                                       allowOverwritePrompt,
                                        allowLossyPrompt,
                                        this))
     {
@@ -1082,7 +1066,7 @@ bool kpMainWindow::slotReload ()
     {
         int result = KMessageBox::Cancel;
 
-        if (d->document->isFromURL (false/*don't bother checking exists*/) && !oldURL.isEmpty ())
+        if (d->document->isFromExistingURL () && !oldURL.isEmpty ())
         {
             result = KMessageBox::warningContinueCancel (this,
                          i18n ("The document \"%1\" has been modified.\n"
@@ -1111,9 +1095,9 @@ bool kpMainWindow::slotReload ()
 
     kpDocument *doc = nullptr;
 
-    // If it's _supposed to_ come from a URL or it exists
-    if (d->document->isFromURL (false/*don't bother checking exists*/) ||
-        (!oldURL.isEmpty () && KIO::NetAccess::exists (oldURL, KIO::NetAccess::SourceSide/*open*/, this)))
+    // If it's _supposed to_ come from an existing URL or it actually exists
+    if (d->document->isFromExistingURL () ||
+        d->document->urlExists (oldURL))
     {
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "kpMainWindow::slotReload() reloading from disk!";
@@ -1333,15 +1317,12 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
         auto *optionsPage = new kpPrintDialogPage (this);
         optionsPage->setPrintImageCenteredOnPage (d->configPrintImageCenteredOnPage);
 
-        QPrintDialog *printDialog =
-            KdePrint::createPrintDialog (
-                printer,
-                QList <QWidget *> () << optionsPage,
-                this);
-        printDialog->setWindowTitle (i18nc ("@title:window", "Print Image"));
+        QPrintDialog printDialog (printer, this);
+        printDialog.setOptionTabs ({optionsPage});
+        printDialog.setWindowTitle (i18nc ("@title:window", "Print Image"));
 
         // Display dialog.
-        const bool wantToPrint = printDialog->exec ();
+        const bool wantToPrint = printDialog.exec ();
 
         if (optionsPage->printImageCenteredOnPage () !=
             d->configPrintImageCenteredOnPage)
@@ -1355,8 +1336,6 @@ void kpMainWindow::sendImageToPrinter (QPrinter *printer,
             cfg.sync ();
         }
 
-        delete printDialog;
-
         if (!wantToPrint) {
             return;
         }
@@ -1413,7 +1392,7 @@ void kpMainWindow::slotMail ()
     toolEndShape ();
 
     if (d->document->url ().isEmpty ()/*no name*/ ||
-        !d->document->isFromURL () ||
+        !(d->document->isFromExistingURL () && d->document->urlExists (d->document->url ())) ||
         d->document->isModified ()/*needs to be saved*/)
     {
         int result = KMessageBox::questionYesNo (this,
