@@ -31,9 +31,9 @@
 #include "mainWindow/kpMainWindow.h"
 #include "kpMainWindowPrivate.h"
 
-#include <qlabel.h>
-#include <qstatusbar.h>
-#include <qstring.h>
+#include <QLabel>
+#include <QStatusBar>
+#include <QString>
 
 #include "kpLogCategories.h"
 #include "kpDefs.h"
@@ -110,12 +110,12 @@ void kpMainWindow::setStatusBarMessage (const QString &message)
 #if DEBUG_STATUS_BAR && 1
     qCDebug(kpLogMainWindow) << "kpMainWindow::setStatusBarMessage("
                << message
-               << ") ok=" << d->statusBarCreated
-               << endl;
+               << ") ok=" << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     d->statusBarMessageLabel->setText (message);
 }
@@ -129,12 +129,12 @@ void kpMainWindow::setStatusBarShapePoints (const QPoint &startPoint,
 #if DEBUG_STATUS_BAR && 0
     qCDebug(kpLogMainWindow) << "kpMainWindow::setStatusBarShapePoints("
                << startPoint << "," << endPoint
-               << ") ok=" << d->statusBarCreated
-               << endl;
+               << ") ok=" << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     if (d->statusBarShapeLastPointsInitialised &&
         startPoint == d->statusBarShapeLastStartPoint &&
@@ -179,12 +179,12 @@ void kpMainWindow::setStatusBarShapeSize (const QSize &size)
 #if DEBUG_STATUS_BAR && 0
     qCDebug(kpLogMainWindow) << "kpMainWindow::setStatusBarShapeSize("
                << size
-               << ") ok=" << d->statusBarCreated
-               << endl;
+               << ") ok=" << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     if (d->statusBarShapeLastSizeInitialised &&
         size == d->statusBarShapeLastSize)
@@ -219,12 +219,12 @@ void kpMainWindow::setStatusBarDocSize (const QSize &size)
 #if DEBUG_STATUS_BAR && 0
     qCDebug(kpLogMainWindow) << "kpMainWindow::setStatusBarDocSize("
                << size
-               << ") ok=" << d->statusBarCreated
-               << endl;
+               << ") ok=" << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     QLabel *statusBarLabel = d->statusBarLabels.at (StatusBarItemDocSize);
     if (size == KP_INVALID_SIZE)
@@ -247,12 +247,12 @@ void kpMainWindow::setStatusBarDocDepth (int depth)
 #if DEBUG_STATUS_BAR && 0
     qCDebug(kpLogMainWindow) << "kpMainWindow::setStatusBarDocDepth("
                << depth
-               << ") ok=" << d->statusBarCreated
-               << endl;
+               << ") ok=" << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     QLabel *statusBarLabel = d->statusBarLabels.at (StatusBarItemDocDepth);
     if (depth <= 0)
@@ -273,12 +273,12 @@ void kpMainWindow::setStatusBarZoom (int zoom)
 #if DEBUG_STATUS_BAR && 0
     qCDebug(kpLogMainWindow) << "kpMainWindow::setStatusBarZoom("
                << zoom
-               << ") ok=" << d->statusBarCreated
-               << endl;
+               << ") ok=" << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     QLabel *statusBarLabel = d->statusBarLabels.at (StatusBarItemZoom);
     if (zoom <= 0)
@@ -301,11 +301,9 @@ void kpMainWindow::recalculateStatusBarMessage ()
     QString scrollViewMessage = d->scrollView->statusMessage ();
 #if DEBUG_STATUS_BAR && 1
     qCDebug(kpLogMainWindow) << "\tscrollViewMessage=" << scrollViewMessage;
-    qCDebug(kpLogMainWindow) << "\tresizing doc? " << !d->scrollView->newDocSize ().isEmpty ()
-               << endl;
+    qCDebug(kpLogMainWindow) << "\tresizing doc? " << !d->scrollView->newDocSize ().isEmpty ();
     qCDebug(kpLogMainWindow) << "\tviewUnderCursor? "
-               << (d->viewManager && d->viewManager->viewUnderCursor ())
-               << endl;
+               << (d->viewManager && d->viewManager->viewUnderCursor ());
 #endif
 
     // HACK: To work around kpViewScrollableContainer's unreliable
@@ -316,8 +314,7 @@ void kpMainWindow::recalculateStatusBarMessage ()
         d->viewManager && d->viewManager->viewUnderCursor ())
     {
     #if DEBUG_STATUS_BAR && 1
-        qCDebug(kpLogMainWindow) << "\t\tnot resizing & viewUnderCursor - message is wrong - clearing"
-                   << endl;
+        qCDebug(kpLogMainWindow) << "\t\tnot resizing & viewUnderCursor - message is wrong - clearing";
     #endif
         d->scrollView->blockSignals (true);
         d->scrollView->clearStatusMessage ();
@@ -365,7 +362,7 @@ void kpMainWindow::recalculateStatusBarShape ()
         const QPoint startPoint (d->document->width (), d->document->height ());
     #if DEBUG_STATUS_BAR && 0
         qCDebug(kpLogMainWindow) << "\thavedMovedFromOrgSize="
-                   << d->scrollView->haveMovedFromOriginalDocSize () << endl;
+                   << d->scrollView->haveMovedFromOriginalDocSize ();
     #endif
         if (!d->scrollView->haveMovedFromOriginalDocSize ())
         {
@@ -409,12 +406,12 @@ void kpMainWindow::recalculateStatusBar ()
 {
 #if DEBUG_STATUS_BAR && 1
     qCDebug(kpLogMainWindow) << "kpMainWindow::recalculateStatusBar() ok="
-               << d->statusBarCreated
-               << endl;
+               << d->statusBarCreated;
 #endif
 
-    if (!d->statusBarCreated)
+    if (!d->statusBarCreated) {
         return;
+    }
 
     recalculateStatusBarMessage ();
     recalculateStatusBarShape ();
